@@ -243,14 +243,18 @@ def callbond_stats(value_date: str,
     ql_callbond.setPricingEngine(engine)
     call_risks = {}
     
-    oas = ql_callbond.OAS(clean_price, 
+    if clean_price is None:
+        c_price = ql_callbond.cleanPrice()
+    else:
+        c_price = clean_price
+    oas = ql_callbond.OAS(c_price, 
                         curve_handle,
                         ql_day_count[call_class.info.settings.day_count],
                         ql.Compounded,
                         ql_frequency[call_class.info.settings.frequency],
                         vdate) * 100
     call_risks["OAS"] =  oas
-    bond_yield  = ql_callbond.bondYield(clean_price,
+    bond_yield  = ql_callbond.bondYield(c_price,
                         ql_day_count[call_class.info.settings.day_count],
                         ql.Compounded,
                         ql_frequency[call_class.info.settings.frequency],
@@ -264,7 +268,7 @@ def callbond_stats(value_date: str,
                                 ql_frequency[call_class.info.settings.frequency])
     call_risks["Effective Convexity"] = e_convex
 
-    e_duration = ql_callbond.effectiveConvexity(oas/100, 
+    e_duration = ql_callbond.effectiveDuration(oas/100, 
                                 curve_handle,
                                 ql_day_count[call_class.info.settings.day_count],
                                 ql.Compounded,
