@@ -22,7 +22,7 @@ def create_fixratestructure(thebond: FixedRateBond,
     interests = ql.FixedRateLeg(schedule, 
                             ql_day_count[setting.day_count],
                             [thebond.face_value], 
-                            [thebond.coupon])
+                            [thebond.coupon/100])
     no_of_interests = len(interests)
     structures = []
     for i in range(no_of_interests):
