@@ -6,6 +6,17 @@ from .ql_utils import *
 from .ql_conventions import *
 from .termstructure import *
 
+
+def flat_forward():
+    thedict = {"date": '2021-02-28',
+                "rate": 5.00,
+                "day_count": DayCount.act_act_act365,
+                "frequency": Frequency.semi_annual,
+                "compounding": Compounding.compounded }
+    ffwd = FlatForwardCurve(**thedict)
+    return ffwd
+
+
 def sample_piecewise(value_date):
     rates, depo_setting, parrates, par_setting = sample_curveinfo()
 
@@ -354,13 +365,31 @@ def sample_floatingrate_structuredloan():
     return loanleg
 
 
+def callabilityschedule(qlSchedule: ql.QuantLib.Schedule):
+    
+    callability_schedule = ql.CallabilitySchedule()
+    call_price = 100.0
+    no_of_dates = len(list(qlSchedule))
+    start = int(no_of_dates/4)
+    #print(start, no_of_dates)
+    for i in range(start, no_of_dates):
+        callability_price  = ql.CallabilityPrice(
+            call_price, ql.CallabilityPrice.Clean)
+        callability_schedule.append(
+                ql.Callability(callability_price, 
+                            ql.Callability.Call,
+                            qlSchedule[i]))
+        print(qlSchedule[i])
+    return callability_schedule
+
+
 def callable_bondinfo():
     bondsetting = {
         "frequency":Frequency.semi_annual,
         "start_basis": StartBasis.today,
         "day_count": DayCount.act_act_isma,
         "business_day": BusinessDay.no_adjustment,
-        "terminate_business_day": BusinessDay.no_adjustment,
+        "terminate_business_day": BusinessDay.following,
         "date_gen": DateGeneration.backward,
         "is_eom":  True
         }
